#
# spec file for package mingetty
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           mingetty
Version:        1.0.8s
Release:        25.5
Summary:        Minimal Getty for Virtual Consoles Only
License:        GPL-2.0-or-later
Group:          System/Base
URL:            http://mingetty.sourceforge.net
Source:         mingetty-1.0.8s.tar.bz2
Patch0:         mingetty-1.0.8s.dif
Provides:       sysvinit:/sbin/mingetty
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The mingetty program is a lightweight, minimalistic getty program for
use on virtual consoles only. Mingetty is not suitable for serial lines
(you should use the mgetty program for this purpose).

%prep
%autosetup -p0

%build
%ifarch s390 s390x
DEFTERM=dumb
%else
DEFTERM=linux
%endif
make \
  %{?_smp_mflags} \
  CC="gcc" \
  RPM_OPT_FLAGS="%{optflags} \
  -D_FILE_OFFSET_BITS=64" \
  DEFTERM=${DEFTERM}

%install
%if 0%{?suse_version} < 1550
mkdir -p ${RPM_BUILD_ROOT}{/sbin,%{_mandir}/man8}
make install MANPATH=%{_mandir} DESTDIR=%{buildroot}
%else
mkdir -p ${RPM_BUILD_ROOT}{%{_sbindir},%{_mandir}/man8}
make install MANPATH=%{_mandir} DESTDIR=%{buildroot} SBINDIR=%{_sbindir}
%endif

%files
%defattr(-,root,root,755)
%if 0%{?suse_version} < 1550
/sbin/mingetty
%else
%{_sbindir}/mingetty
%endif
%{_mandir}/man8/mingetty.8.gz

%changelog
* Fri Feb 23 2024 pgajdos@suse.com
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Tue Dec 27 2022 Ludwig Nussel <lnussel@suse.com>
- Replace transitional %%usrmerged macro with regular version check (boo#1206798)
* Thu Sep 30 2021 Dr. Werner Fink <werner@suse.de>
- Move to /usr for UsrMerge (boo#1191077)
* Sun Jul 12 2015 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
- Add project url
* Fri Sep 30 2011 uli@suse.com
- cross-build fix: use %%__cc macro
* Tue Mar 15 2011 werner@suse.de
- Make hint handling on Num Lock et al smart (bnc#679287)
* Wed Jan 12 2011 werner@suse.de
- Fix Num Lock handling (bug #656876)
* Mon Jul 26 2010 werner@suse.de
- Make a clean tar ball
* Sun Jul 25 2010 aj@suse.de
- Remove packaged object files to fix build on non-i386 architectures.
* Fri Jul 23 2010 werner@suse.de
- New version mingetty 1.0.8s
  * Adopt loginpause feature of the other mingetty at sourceforge.
  * Ignore SIGQUIT and SIGINT and switch Numlock on.
* Tue Dec 22 2009 jengelh@medozas.de
- Enable parallel build
- Change DEFTERM=dump - it probably should have been "dumb"
* Thu Dec  4 2008 werner@suse.de
- Do open the terminal with O_NOCTTY (bnc#447289)
* Thu Dec  4 2008 werner@suse.de
- Get the controlling tty only if we do not have it (bnc#447289)
* Mon Jul 21 2008 werner@suse.de
- Use the enlarged buffer of last change
* Fri Apr 25 2008 werner@suse.de
- Increase buffer size for scanning /proc/<pid>/maps
* Tue Apr 22 2008 werner@suse.de
- Fix possible SIGSEGV in mingetty sigfholder()  (bnc#382052)
* Tue May 29 2007 werner@suse.de
- Adopt autologin and other new feature of the other mingetty
  at sourceforge.
* Wed May 24 2006 schwab@suse.de
- Don't strip binaries.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Mar 30 2004 werner@suse.de
- Remove kernel include hopefully glibc does this jobs for now
  and in future.
* Tue Mar 30 2004 werner@suse.de
- More about UTF-8: enable the kernel to erease UTF-8 multi byte
  characters (bug #37367)
- Therefore add workaround if glibc bits/termios.h is missing
  the IUTF8 input flag.
* Fri Mar 26 2004 werner@suse.de
- Not all architectures do provide KDGKBMODE ioctl (s390/s390x)
* Wed Feb 18 2004 werner@suse.de
- Add UTF-8 support for login name if and only if current console
  is in utf-8 mode (fix bug #34520)
* Sat Oct 18 2003 kukuk@suse.de
- Move mingetty in extra package
- Build as normal user
* Thu Jun  5 2003 mfabian@suse.de
- if the option "--noclear" is not set, don't write a full reset
  because this leaves the unicode mode again if the terminal was in
  unicode mode and it also undos the ESC sequences in CONSOLE_MAGIC
  which are needed for some languages/console-fonts.
  Just put the cursor the home position (ESC [ H) and erase
  everything below the cursor (ESC [ J).
* Thu Nov 14 2002 werner@suse.de
- Update to mingetty 0.9.6s
  * Be sure to get controlling tty
  * Avoid overruns in string handling
* Wed Nov 13 2002 werner@suse.de
- Update to mingetty 0.9.5s (s stand for SuSE)
  * New old option for avoiding vcs/vcsa hangup, terminal
    reset, and the usage of the glibc for updating wtmp.
  * Now the default terminal type can be set at compile
    time as an make option.
* Thu Apr 25 2002 werner@suse.de
- changes on mingetty (new version 0.9.4c)
  * Add support for other TTY devices than virtual console
  * Add nohost patch from Anders ??
* Mon Apr 19 1999 werner@suse.de
- mingetty: reset not only /dev/tty<line> but /dev/vcs<line> and
  /dev/vcsa<line> also
